Mode

Enum Mode 

pub enum Mode {
    Client {
        client_id: Option<u64>,
    },
    Server,
    Separate {
        client_id: Option<u64>,
    },
    HostClient {
        client_id: Option<u64>,
    },
}

Variants



Client

Runs the app in client mode

Fields

client_id: Option<u64>


Server

Runs the app in server mode



Separate

Creates two bevy apps: a client app and a server app. Data gets passed between the two via channels.

Fields

client_id: Option<u64>


HostClient

Run the app in host-client mode. The client and the server will run inside the same app. The peer acts both as a client and a server.

Fields

client_id: Option<u64>